#[non_exhaustive]pub struct GcGenParams {
pub minor_multiplier: Option<c_int>,
pub minor_to_major: Option<c_int>,
pub major_to_minor: Option<c_int>,
}Available on crate features
lua55 or lua54 only.Expand description
Tuning parameters for the generational GC collector (Lua 5.4+).
More information can be found in the Lua documentation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.minor_multiplier: Option<c_int>Frequency of minor (young-generation) collection steps.
minor_to_major: Option<c_int>Threshold controlling how large the young generation can grow before triggering a shift from minor to major collection.
major_to_minor: Option<c_int>Available on crate feature
lua55 only.Threshold controlling how much the major collection must shrink the heap before switching back to minor (young-generation) collection.
Implementations
Sourceimpl GcGenParams
impl GcGenParams
Sourcepub fn minor_multiplier(self, v: c_int) -> Self
pub fn minor_multiplier(self, v: c_int) -> Self
Sets the minor_multiplier parameter.
Sourcepub fn minor_to_major(self, v: c_int) -> Self
pub fn minor_to_major(self, v: c_int) -> Self
Sets the minor_to_major threshold.
Sourcepub fn major_to_minor(self, v: c_int) -> Self
Available on crate feature lua55 only.
pub fn major_to_minor(self, v: c_int) -> Self
lua55 only.Sets the major_to_minor parameter.