#[non_exhaustive]pub struct GcIncParams {
pub pause: Option<c_int>,
pub goal: Option<c_int>,
pub step_multiplier: Option<c_int>,
pub step_size: Option<c_int>,
}Expand description
Tuning parameters for the incremental GC collector.
More information can be found in the Lua documentation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pause: Option<c_int>Available on non-crate feature
luau only.Pause between successive GC cycles, expressed as a percentage of live memory.
goal: Option<c_int>Available on crate feature
luau only.Target heap size as a percentage of live data, controlling how aggressively
the GC reclaims memory (LUA_GCSETGOAL).
step_multiplier: Option<c_int>GC work performed per unit of memory allocated.
step_size: Option<c_int>Available on crate features
lua55 or lua54 or luau only.Granularity of each GC step (see Lua reference for details).
Implementations
Sourceimpl GcIncParams
impl GcIncParams